@@ -52,7 +52,7 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 =cut
 
-# $Id: docbook2man-spec.pl,v 1.7 2002/07/28 18:01:26 twaugh Exp $
+# $Id: docbook2man-spec.pl,v 1.9 2002/10/14 14:26:35 twaugh Exp $
 
 use SGMLS;			# Use the SGMLS package.
 use SGMLS::Output;		# Use stack-based output.
@@ -244,6 +244,14 @@ sgml('<REFENTRY>', sub {
 	$manpage_misc = '';
 	
 	$list_nestlevel = 0;		# Indent certain nested content.
+
+	# check refentry's language
+	if(defined($_[0]->attribute('LANG')->value)) {
+	  $manpage_lang = $_[0]->attribute('LANG')->value;
+	}
+	else {
+	  $manpage_lang = '';
+	}
 });
 sgml('</REFENTRY>', sub {
 	if(!$newline_last) {
@@ -256,7 +264,11 @@ sgml('</REFENTRY>', sub {
 });
 
 sgml('</REFMETA>', sub {
-	push_output('file', "$manpage_title.$manpage_sect");
+	if ($manpage_lang) {
+		push_output('file', "$manpage_title.$manpage_lang.$manpage_sect");
+	} else {
+		push_output('file', "$manpage_title.$manpage_sect");
+	}
 
 	output <<_END_BANNER;
 .\\" This manpage has been automatically generated by docbook2man 
@@ -344,7 +356,14 @@ sgml('</REFMISCINFO>', sub {
 
 
 # NAME section
-man_sgml('<REFNAMEDIV>', "\n.SH NAME\n");
+man_sgml('<REFNAMEDIV>', sub {
+	my %words = qw( fr NOM es NOMBRE de NAME );
+	if (defined($_[0]->attribute('LANG')->value)) {
+	my $id = $_[0]->attribute('LANG')->value;
+	my $ad = $words{$id};
+	output("\n.SH $ad\n");}
+	else {output("\n.SH NAME\n");}
+});
 
 sgml('<REFNAME>', \&save_cdata);
 sgml('</REFNAME>', sub { 
